@@ -40,6 +40,8 @@ unsigned Bayonne::idle_limit = 0;
 bool Bayonne::shutdown_flag = false;
 time_t Bayonne::start_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
+unsigned Bayonne::compile_count;
+
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -398,6 +400,7 @@ void Bayonne::compileDir(const char *prefix, ScriptCompiler *img)
 		if(!ext || stricmp(ext, ".scr"))
 			continue;
 compile:
+		++compile_count;
 		setString(pp, len, file);
 		img->compile(path);
 	}
@@ -437,7 +440,7 @@ void Bayonne::compileApps(const char *prefix, ScriptCompiler *img)
 
 		continue;
 compile:
-
+		++compile_count;
 		setString(pp, len, file);
 		img->compile(path);
 	}
@@ -509,6 +512,7 @@ ScriptCompiler *Bayonne::reload(void)
 	if(!server)
 		return NULL;
 
+	compile_count = 0;
 
 	lock.enter();
 #ifdef	WIN32
@@ -534,6 +538,7 @@ ScriptCompiler *Bayonne::reload(void)
 		if(!ext || stricmp(ext, ".scr"))
 			continue;
 compile:
+		++compile_count;
 		prefix = server->getLast(prefix);
 		img->compile(prefix);
 	}
