@@ -54,6 +54,7 @@
 #define	MAX_DTMF	32
 #define	MAX_LIST	256
 #define	MAX_LIBINPUT	256
+#define	MAX_PATHNAME	256
 
 #ifdef	WIN32
 #define	PFD_INVALID	INVALID_HANDLE_VALUE
@@ -106,6 +107,7 @@ public:
 	static timeout_t step_timer;
 	static timeout_t reset_timer;
 	static timeout_t exec_timer;
+	static unsigned compile_count;
 
 	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
@@ -414,6 +416,7 @@ public:
 		PART_EXIT,
 		JOIN_PEER,
 		PEER_WAITING,
+		PART_PEER,
 
 		// master control events
 
@@ -1017,7 +1020,7 @@ public:
 class __EXPORT BayonneAudio : public AudioStream, public Bayonne
 {
 protected:
-	char filename[256];
+	char filename[MAX_PATHNAME];
 	const char **list;
 	char *getContinuation(void);
 
@@ -1729,6 +1732,8 @@ protected:
 
 	timeout_t getLibexecTimeout(void);
 
+	const char *getWritepath(char *buf = NULL, size_t len = 0);
+
 public:
 	/**
 	 * Process interpreter session symbols.
@@ -1883,6 +1888,9 @@ public:
 	 */
 	virtual ~BayonneSession();
 
+	inline const char *defVoicelib(void)
+		{return voicelib;}
+
 	/**
 	 * Initial kickoff event.
 	 */
