@@ -45,6 +45,7 @@ Libexec::Libexec()
 	setString(position, sizeof(position), "00:00:00.000");	
 	exitcode = 0;
 	reply = 0;
+	level = 0;
 	result = RESULT_SUCCESS;
 
 	voice = NULL;
@@ -358,7 +359,7 @@ bool Libexec::waitInput(timeout_t timeout)
 	return false;
 }   
 
-char Libexec::inkey(timeout_t timeout)
+char Libexec::readKey(timeout_t timeout)
 {
 	char buffer[32];
 	char inbuf[2];
@@ -367,7 +368,7 @@ char Libexec::inkey(timeout_t timeout)
 	return inbuf[0];
 }
 
-Bayonne::result_t Libexec::getline(char *ib, unsigned size, timeout_t timeout)
+Bayonne::result_t Libexec::readInput(char *ib, unsigned size, timeout_t timeout)
 {
 	char buffer[32];
 	snprintf(buffer, sizeof(buffer), "READ %ld %d", timeout, size - 1);
@@ -409,6 +410,31 @@ Bayonne::result_t Libexec::sendResult(const char *code)
 	return sendCommand(buffer);
 }
 
+Bayonne::result_t Libexec::playSingleTone(short f1, timeout_t duration, unsigned l)
+{
+	char buffer[512];
+	if(!l)
+		l = level;
+	snprintf(buffer, sizeof(buffer), "STONE %d %ld %d", f1, duration, l);
+}
+
+Bayonne::result_t Libexec::playDualTone(short f1, short f2, timeout_t duration, unsigned l)
+{
+        char buffer[512];
+        if(!l)
+                l = level;
+        snprintf(buffer, sizeof(buffer), "DTONE %d %d %ld %d", f1, f2, duration, l);
+}
+
+Bayonne::result_t Libexec::playTone(const char *tone, timeout_t timeout, unsigned _level)
+{
+	char buffer[512];
+	if(!_level)
+		_level = level;
+	snprintf(buffer, sizeof(buffer), "TONE %s %ld %d", tone, timeout, _level);
+	return sendCommand(buffer);
+}
+
 Bayonne::result_t Libexec::speak(const char *format, ...)
 {
 	va_list args;
