@@ -35,8 +35,11 @@ static Keydata::Define driver[] = {
 	{"inband", "false"},
 	{"silence", "500"},
 	{"duration", "3600"},
-	{"acktimer", "2000"},
+	{"pickup", "2000"},
+	{"accept", "320"},
+	{"audio", "200"},
 	{"jitter", "2"},
+	{"filler", "false"},
 #ifdef	WIN32		// use localhost default if not in conf for w32
 	{"interface", "127.0.0.1:5070"},
 #endif
@@ -69,6 +72,9 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	if(!cp)
 		cp = getLast("acktimer");
 
+	if(!cp)
+		cp = getLast("pickup");
+
 	if(cp)
 		pickup_timer = atoi(cp);
 
@@ -118,6 +124,24 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		break;
 	}
 
+        cp = getLast("filler");
+
+        data_filler = true;
+        switch(*cp)
+        {
+        case 'n':
+        case 'N':
+        case 'f':
+        case 'F':
+        case '0':
+        case 0:
+                data_filler = false;
+                break;
+        }
+
+
+	audio_timer = atol(getLast("audio"));
+	accept_timer = atol(getLast("accept"));
 	jitter = atoi(getLast("jitter"));
 	data_payload = atoi(getLast("payload"));
 	dtmf_payload = 0;
