@@ -53,9 +53,12 @@ protected:
 	bool registry;
 	bool exiting;
 	bool dtmf_inband;
+	bool data_filler;
 	Level silence;
 	Linear silent_frame;
 	unsigned jitter;
+	timeout_t accept_timer;
+	timeout_t audio_timer;
 
 public:
 	static Driver sip;		// plugin activation
