@@ -81,17 +81,21 @@ void RTPStream::start(void)
 void RTPStream::setTone(AudioTone *t, timeout_t max)
 {
 	enter();
+	jsend = Driver::sip.jitter;
 	tone = t;
 	fcount = max / info.framing;
+	oTimestamp = 0;
 	leave();
 }
 
 void RTPStream::setSource(AudioBase *get, timeout_t max)
 {
         enter();
+	jsend = Driver::sip.jitter + 1;
 	ending = false;
         source = get;
 	fcount = max / info.framing;
+	oTimestamp = 0;
         leave();
 }
 
@@ -202,12 +206,7 @@ post:
 		return false;
 	}				
 
-	if(session->postEvent(&event))
-	{
-		setSource(NULL);
-		setSink(NULL);
-		setTone(NULL);
-	}
+	session->queEvent(&event);
 
 checkbit:
 	if(evt->ebit && tonecount && stopid != MSGPORT_WAKEUP)
@@ -215,7 +214,7 @@ checkbit:
 		memset(&event, 0, sizeof(event));
 		event.id = stopid;
 		stopid = MSGPORT_WAKEUP;
-		session->postEvent(&event);
+		session->queEvent(&event);
 		tonecount = 0;
 	}
 	else if(evt->ebit)
@@ -269,17 +268,20 @@ void RTPStream::run(void)
 	char dbuf[65];
 	int dig;
 	Linear tbuf;
+	bool silent;
 
 	jitter = Driver::sip.jitter;
-	jsend = jitter;
+	jsend = Driver::sip.jitter;
 
 	if(Driver::sip.getDTMFInband())
 		dtmf = new DTMFDetect();
 
         setTimer(0);
 
+	setCancel(cancelDeferred);
         for(;;)
         {
+		silent = true;
 		if(dtmfdigits)
 		{
 			dtmf->getResult(dbuf, 64);
@@ -292,12 +294,7 @@ void RTPStream::run(void)
 				event.id = DTMF_KEYUP;
 				event.dtmf.digit = dig;
 				event.dtmf.duration = 60;
-				if(session->postEvent(&event))
-				{
-					setSource(NULL);
-					setSink(NULL);
-					setTone(NULL);
-				}
+				session->queEvent(&event);
 			}			
 			dtmfdigits = false;
 		}
@@ -319,12 +316,13 @@ void RTPStream::run(void)
 			{
 				codec->encode(tbuf, session->buffer, info.framecount);
 				putBuffer(session->buffer, size);
-//				r = dispatchDataPacket();
+				silent = false;
 			}				
 			if(jsend)
 			{
 				--jsend;
 				leave();
+				dispatchDataPacket();
 				continue;
 			}
 			
@@ -341,6 +339,7 @@ void RTPStream::run(void)
 					session->queEvent(&event);
 					ending = false;
 				}
+				silent = false;
 	                        putBuffer(session->buffer, size);
 			}
 			else if(!ending)
@@ -351,19 +350,25 @@ void RTPStream::run(void)
 				session->queEvent(&event);
 				ending = true;
 			}
-//                        r = dispatchDataPacket();
-			if(jsend)
+			if(jsend && !silent)
 			{
 				--jsend;
 				leave();
+				dispatchDataPacket();
 				continue;
 			}
                 }
 		else if(!session->peer)
-			jsend = jitter;
+			jsend = Driver::sip.jitter;
 
 done:
-                leave();
+		leave();
+		if(silent && Driver::sip.data_filler)
+		{
+			silent = false;
+			putBuffer((Encoded)Driver::sip.silent_frame, info.framesize);
+		}
+
 		r = dispatchDataPacket();
 
 		if(tonecount == 1 && stopid != MSGPORT_WAKEUP)
@@ -447,8 +452,10 @@ done:
 
                 timer = getTimer();
 
-                if(timer)
-                        Thread::sleep(timer);
+		if(timer > info.framing + 5)
+			timer = info.framing + 5;
+		if(timer > 5)
+                        Thread::sleep(timer - 5);
 		else
 			Thread::yield();
 
@@ -463,7 +470,7 @@ done:
 			tone = NULL;
 			memset(&event, 0, sizeof(event));
 			event.id = AUDIO_IDLE;
-			session->postEvent(&event);
+			session->queEvent(&event);
 		}
 		leave();		
         }
