@@ -150,6 +150,9 @@ bool Session::enterPlay(Event *event)
 {
 	switch(event->id)
 	{
+	case AUDIO_IDLE:
+		startTimer(Driver::sip.audio_timer);
+		return true;
 	case ENTER_STATE:
 		if(state.audio.mode == Audio::modeReadAny)
 			update_pos = false;
@@ -180,8 +183,7 @@ bool Session::enterPickup(Event *event)
 	}
 	else if(event->id == CALL_ACCEPTED)
 	{
-		stopTimer();
-		setRunning();
+		startTimer(Driver::sip.accept_timer);
 		return true;
 	}
 
