@@ -1,18 +1,32 @@
-# Copyright (C) 2005 David Sugar, Tycho Softworks    
-#
-# This file is free software; as a special exception the author gives
-# unlimited permission to copy and/or distribute it, with or without
-# modifications, as long as this notice is preserved.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
-# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
-#
-# Bayonne perl libexec interface module.
-
 package Bayonne::Libexec;
 
-require 5.004;
+use 5.008004;
+use strict;
+use warnings;
+
+require Exporter;
+use AutoLoader qw(AUTOLOAD);
+
+our @ISA = qw(Exporter);
+
+# Items to export into callers namespace by default. Note: do not export
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+
+# This allows declaration       use Bayonne::Libexec ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory. 
+our %EXPORT_TAGS = ( 'all' => [ qw(
+
+) ] );
+
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = qw(
+
+);
+ 
+our $VERSION = '0.02'; 
 
 # disable buffering
 $|=1;
@@ -21,55 +35,62 @@ sub new {
 	my ($class, %args) = @_;
 	my $self = {};
 	my ($buffer);
+	my ($num);
 
 	# default voice
-	$self->{voice} = "";
+	$self->{'voice'} = "";
 
 	# digits buffer
-	$self->{digits} = "";
+	$self->{'digits'} = "";
 
 	# query buffer
-	$self->{query} = "";
+	$self->{'query'} = "";
 
 	# audio position
-	$self->{position} = "00:00:00.000";
+	$self->{'position'} = "00:00:00.000";
 
 	# last header reply id number
-	$self->{reply} = 0;
+	$self->{'reply'} = 0;
 
 	# last result code from a transaction.
-	$self->{result} = 0;
+	$self->{'result'} = 0;
 
 	# exit code if terminated by server, 0 if active
-	$self->{exitcode} = 0;
+	$self->{'exitcode'} = 0;
 
 	# version of our interface
-	$self->{version} = "4.0";
+	$self->{'version'} = "4.0";
 
 	# audio level of tones...
-	$self->{level} = 0;
+	$self->{'level'} = 0;
 
-	$self->{tsession} = $ENV{'PORT_TSESSION'} if $ENV{'PORT_TSESSION'};
+	$self->{'tsession'} = $ENV{'PORT_TSESSION'} if $ENV{'PORT_TSESSION'};
 	
-	if(!$self->{tsession}) {
-		$self->{exitcode} = 1;
+	if(!$self->{'tsession'}) {
+		$self->{'exitcode'} = 1;
 	        bless $self, ref $class || $class;
         	return $self;   
 	}
 
 	# issue libexec HEAD request to get headers...
 
-	print STDOUT "$self->{tsession} HEAD\n";
+	print STDOUT "$self->{'tsession'} HEAD\n";
 	while(<STDIN>)
 	{
 		$buffer = $_;
-		if($buffer > 900) {
-			$self->{reply} = $buffer - 0;
-			$self->{exitcode} = $buffer - 900;
+		$num = 0;
+
+		if(length($buffer) > 0 && substr($buffer, 0, 1) gt '0' && substr($buffer, 0, 1) le '9') {
+                        $num = 0 + substr($buffer, 0, 3);
+                }  
+
+		if($num > 900) {
+			$self->{'reply'} = $num - 0;
+			$self->{'exitcode'} = $num - 900;
 			last;
 		}
-		if($buffer > 0) {
-			$self->{reply} = $buffer - 0;
+		if($num > 0) {
+			$self->{'reply'} = $num - 0;
 			next;
 		}
 		if($buffer eq "\n") {
@@ -79,24 +100,28 @@ sub new {
 		my($keyword, $value) = ($1, $2);
 		$value =~ s/\s+$//;
 		if($keyword eq "DIGITS") {
-			$self->{digits} = $value;
+			$self->{'digits'} = $value;
 		}
 		$self->{head}{$keyword}=$value;
 	}
 
 	# issue libexec ARGS request to get command arguments...
 
-	print STDOUT "$self->{tsession} ARGS\n";
+	print STDOUT "$self->{'tsession'} ARGS\n";
 	while(<STDIN>)
 	{
 		$buffer = $_;
-		if($buffer > 900) {
-			$self->{reply} = $buffer - 0;
-			$self->{exitcode} = $buffer - 900;
+		$num = 0;
+		if(length($buffer) > 0 && substr($buffer, 0, 1) gt '0' && substr($buffer, 0, 1) le '9') {
+                        $num = 0 + substr($buffer, 0, 3);
+                }  
+		if($num > 900) {
+			$self->{'reply'} = $num - 0;
+			$self->{'exitcode'} = $num - 900;
 			last;
 		}
-		if($buffer > 0) {
-			$self->{reply} = $buffer - 0;
+		if($num > 0) {
+			$self->{'reply'} = $num - 0;
 			next;
 		}
 		if($buffer eq "\n") {
@@ -116,10 +141,10 @@ sub new {
 
 sub hangup($) {
 	my($self) = @_;
-	my($tsid) = $self->{tsession};
+	my($tsid) = $self->{'tsession'};
 	if($tsid) {
 		print STDOUT "$tsid hangup\n";
-		$self->{tsession} = undef;
+		$self->{'tsession'} = undef;
 	}
 }
 
@@ -127,21 +152,21 @@ sub hangup($) {
 
 sub detach($$) {
 	my($self,$code) = @_;
-	my($tsid) = $self->{tsession};
+	my($tsid) = $self->{'tsession'};
 
 	if($tsid) {
 		print STDOUT "$tsid exit $code\n";
-		$self->{tsession} = undef;	
+		$self->{'tsession'} = undef;	
 	}
 }
 
 sub pathname($$) {
 	my($self,$file) = @_;
-	my $prefix = $self->{head}{PREFIX};
+	my $prefix = $self->{head}{'PREFIX'};
 	my $var = $ENV{'SERVER_PREFIX'};
 	my $ram = $ENV{'SERVER_TMPFS'};
 	my $tmp = $ENV{'SERVER_TMP'};
-	my $ext = $self->{head}{EXTENSION};
+	my $ext = $self->{head}{'EXTENSION'};
 
 	if(!$file) {
 		return undef;
@@ -177,7 +202,7 @@ sub pathname($$) {
 	$_ = $file;
 	$count = tr:/::;
 	if($count < 1) {
-		if(!prefix or $prefix == "") {
+		if(!$prefix or $prefix == "") {
 			return undef;
 		}
 		return "$var/$prefix/$file";
@@ -189,7 +214,7 @@ sub pathname($$) {
 
 sub filename($$) {
 	my($self,$file) = @_;
-	my $prefix = $self->{head}{PREFIX};
+	my $prefix = $self->{head}{'PREFIX'};
 
 	if(!$file) {
 		return undef;
@@ -233,11 +258,11 @@ sub move($$$) {
 	$file1 = $self->pathname($file1);
 	$file2 = $self->pathname($file2);
 	if(!$file1 || !$file2) {
-		self->{result} = 254;
+		$self->{'result'} = 254;
 		return 254;
 	}
 	rename($file1, $file2);
-	self->{result} = 0;
+	$self->{'result'} = 0;
 	return 0;
 }	
 
@@ -247,11 +272,11 @@ sub erase($$) {
 	my ($self,$file) = @_;
 	$file = $self->pathname($file);
 	if(!$file) {
-		self->{result} = 254;
+		$self->{'result'} = 254;
 		return 254;
 	}
 	remove("$file");
-	self->{result} = 0;
+	$self->{'result'} = 0;
 	return 0;
 }
 
@@ -268,7 +293,7 @@ sub tone {
 	}
 
 	if(!$level) {
-		$level = $self->{level}; 	
+		$level = $self->{'level'}; 	
 	}
 	return $self->command("tone $tone $duration $level");
 }
@@ -284,7 +309,7 @@ sub single_tone {
 	}
 
 	if(!$level) {
-		$level = $self->{level}; 	
+		$level = $self->{'level'}; 	
 	}
 	return $self->command("stone $tone $duration $level");
 }
@@ -301,7 +326,7 @@ sub dual_tone {
 	}
 
 	if(!$level) {
-		$level = $self->{level}; 	
+		$level = $self->{'level'}; 	
 	}
 	return $self->command("dtone $tone1 $tone2 $duration $level");
 }
@@ -316,7 +341,7 @@ sub replay {
 	$file = $self->filename($file);
 
 	if(!$file) {
-		self->{result} = 254;
+		$self->{'result'} = 254;
 		return "255";
 	}
 
@@ -339,7 +364,7 @@ sub record {
 	$file = $self->filename($file);
 
 	if(!$file) {
-		self->{result} = 254;
+		$self->{'result'} = 254;
 		return "254";
 	}
 
@@ -371,12 +396,12 @@ sub voice {
 	my $self = shift;
 	my $voice = shift;
 
-	$self->{voice} = $voice;
+	$self->{'voice'} = $voice;
 }
 
 sub level($$) {
 	my($self, $level) = @_;
-	$self->{level} = $level;
+	$self->{'level'} = $level;
 }
 
 # process input line
@@ -397,7 +422,7 @@ sub input($$$) {
 		return "";
 	}
 
-	return $self->{digits};
+	return $self->{'digits'};
 }
 
 # clear pending input
@@ -417,9 +442,9 @@ sub wait($$) {
 	}
 	my $result = $self->command("WAIT $timeout");
 	if($result == 3) {
-		return true;
+		return 1;
 	}
-	return false;
+	return 0;
 }
 
 # process single key input
@@ -435,7 +460,7 @@ sub inkey($$) {
 	if($result != 0) {
 		return "";
 	}
-	return substr($self->{digits}, 0, 1);
+	return substr($self->{'digits'}, 0, 1);
 }
 
 # send results back to server.
@@ -454,7 +479,7 @@ sub result($$) {
 sub get($$) {
 	my($self, $buf) = @_;
 	$self->command("get $buf");
-	return $self->{query};
+	return $self->{'query'};
 }
 
 # set symbol value
@@ -481,7 +506,7 @@ sub size($$$) {
 
 sub speak($$) {
         my($self, $buf) = @_;
-	my($voice) = $self->{voice};
+	my($voice) = $self->{'voice'};
 
 	if(!$voice) {
 		$voice = "prompt";
@@ -500,8 +525,11 @@ sub command($$) {
 	my($self,$buf) = @_;
         my($hid) = 0;
         my($result) = 255;      # no result value   
-	my($tsession) = $self->{tsession};
-	my($exitcode) = $self->{exitcode};
+	my($tsession) = $self->{'tsession'};
+	my($exitcode) = $self->{'exitcode'};
+	my($buffer);
+	my($num);
+
 	if(!$tsession || $exitcode > 0) {
 		return -$exitcode;
 	}
@@ -509,20 +537,25 @@ sub command($$) {
         $buf =~ s/(.)/ord $1 < 32 ?
                 sprintf "%%%s", chr(ord($1) + 64) : sprintf "%s",$1/eg; 
 
-	$self->{query} = "";
+	$self->{'query'} = "";
 	print STDOUT "$tsession $buf\n";
 
 	while(<STDIN>)
         {
                 $buffer = $_;
-                if($buffer > 900) {
-                        $self->{reply} = $buffer - 0;
-                        $self->{exitcode} = $buffer - 900;
+		$num = 0;
+		if(length($buffer) > 0 && substr($buffer, 0, 1) gt '0' && substr($buffer, 0, 1) le '9') {
+			$num = 0 + substr($buffer, 0, 3);
+		}
+			
+                if($num > 900) {
+                        $self->{'reply'} = $num - 0;
+                        $self->{'exitcode'} = $num - 900;
                         last;      
                 }      	
-                if($buffer > 0) {
-                        $self->{reply} = $buffer - 0;
-			$hid = $buffer - 0;
+                if($num > 0) {
+                        $self->{'reply'} = $num - 0;
+			$hid = $num - 0;
                         next;
                 } 
 		if($buffer eq "\n") {
@@ -553,11 +586,54 @@ sub print($$) {
   	$buf =~ s/\%/\%\%/g; 
   	$buf =~ s/(.)/ord $1 < 32 ? 
 		sprintf "%%%s", chr(ord($1) + 64) : sprintf "%s",$1/eg; 
-	if($self->{tsession}) {
+	if($self->{'tsession'}) {
 		print STDERR $buf;
 	} else {
 		print STDOUT $buf;
 	}
 }
 1;
+__END__
 
+=head1 NAME
+
+Bayonne::Libexec - Perl extension for executing applications under Bayonne 2
+
+=head1 SYNOPSOS
+
+  use Bayonne::Libexec;
+  $TGI = new Bayonne::Libexec;
+
+=head1 DESCRIPTION
+
+  This module is used to create an instance of the Bayonne::Libexec.  You
+  only need to create one instance.  The Bayonne::Libexec object includes
+  member functions which issue commands to the running Bayonne server that
+  the application was launched from, and receives reply messages.
+
+=head1 EXPORT
+
+None by default.
+
+=head1 SEE ALSO
+
+Documentation for GNU Bayonne 2.  Support is available from the Bayonne 2
+developers mailing list, bayonne-devel@gnu.org.
+
+=head1 AUTHOR
+
+David Sugar, E<lt>dyfet@gnutelephony.orgE<gt> 
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2005 by David Sugar, Tycho Softworks
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available. 
+
+
+=cut
+
+
+  
