@@ -274,6 +274,7 @@ static void commonConfig(void)
 	runtime.setValue("tmp", keypaths.getLast("tmp"));
 	runtime.setValue("tmpfs", keypaths.getLast("tmpfs"));
 	runtime.setValue("prompts", keypaths.getLast("prompts"));
+	runtime.setValue("prefix", keypaths.getLast("datafiles"));
 	runtime.setValue("voice", keyserver.getLast("voice"));
 	runtime.setValue("logfiles", keypaths.getLast("logfiles"));
 	runtime.setValue("runfiles", keypaths.getLast("runfiles"));
@@ -355,6 +356,9 @@ void testConfig(char *argv0)
 	keypaths.setValue("scripts", "../scripts");
 	keypaths.setValue("macros", "../scripts");
 	keypaths.setValue("config", "../config");
+	keypaths.setValue("datafiles", "tempfiles");
+	keypaths.setValue("logfiles", "tempfiles");
+	keypaths.setValue("runfiles", "tempfiles");
 	Process::setEnv("DRIVERCONFIG", "../config/driver.conf", true);
 	Process::setEnv("MODULECONFIG", "../config/module.conf", true);
 	Process::setEnv("SPANCONFIG", "../config/spans.conf", true);
@@ -378,10 +382,10 @@ void testConfig(char *argv0)
 	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
 	keypaths.setValue("macros", SOURCE_FILES "/macros");
 	keypaths.setValue("config", SOURCE_FILES "/config");
+	keypaths.setValue("datafiles", SOURCE_FILES "/server/tempfiles");
+	keypaths.setValue("logfiles", SOURCE_FILES "/server/tempfiles");
+	keypaths.setValue("runfiles", SOURCE_FILES "/server/tempfiles");
 #endif
-	keypaths.setValue("datafiles", "tempfiles");
-	keypaths.setValue("logfiles", "tempfiles");
-	keypaths.setValue("runfiles", "tempfiles");
 	keypaths.setValue("modexec", "../scripts");
 	Dir::create("tempfiles");
 	keyserver.setValue("state", "test");
@@ -557,6 +561,14 @@ retry:
                 goto retry;
         }
 
+	if(!stricmp(option, "-p"))
+	{
+		keyengine.setValue("priority", "2");
+		keyengine.setValue("scheduler", "fifo");
+		++argv;
+		goto retry;
+	}
+
 	if(!strnicmp(option, "-sip=", 5))
 	{
 		runtime.setValue("slots.sip", option + 5);
